@@ -150,7 +150,7 @@ class PDFQuery(object):
                     input_text_formatter=None,
                     normalize_spaces=True,
                     resort=True,
-                    parse_tree_cacher=FileCache("/tmp/"),
+                    parse_tree_cacher=None,
                     ):
         # store input
         self.merge_tags = merge_tags
